@@ -19,6 +19,7 @@ use strict;
 #</Location>
 
 use Apache::RequestRec ();
+use Apache::SubRequest ();
 use Apache::Connection ();
 use Apache::Server ();
 use Apache::ServerUtil ();
@@ -98,6 +99,15 @@ sub gensym {
     return Symbol::gensym();
 }
 
+sub define {
+    shift if @_ == 2;
+    exists_config_define(@_);
+}
+
+sub log_error {
+    Apache->server->log_error(@_);
+}
+
 package Apache::Constants;
 
 use Apache::Const ();
@@ -320,6 +330,8 @@ sub send_fd {
     $r->send_fd_length($fh, -1);
 }
 
+sub is_main { !shift->main }
+
 package Apache::File;
 
 use Fcntl ();
