@@ -6,6 +6,7 @@ use mod_perl ();
 use Apache::Build ();
 
 use Apache::TestConfig ();
+use Apache::TestTrace;
 
 our $VERSION = '0.01';
 our @ISA = qw(Apache::Build);
@@ -198,7 +199,7 @@ sub generate_handler_hooks {
             if (my $hook = $hooks{$handler}) {
                 next if $not_ap_hook{$hook};
                 push @register_hooks,
-                  "    ap_hook_$hook($name, NULL, NULL, APR_HOOK_LAST);";
+                  "    ap_hook_$hook($name, NULL, NULL, APR_HOOK_FIRST);";
             }
 
             my($protostr, $pass) = canon_proto($prototype, $name);
@@ -259,6 +260,16 @@ EOF
         my $names = $switch{$key};
         print $c_fh "      case '$key':\n";
 
+        #support $r->push_handlers(PerlHandler => ...)
+        if ($key eq 'H') {
+            print $c_fh <<EOF;
+          if (strEQ(name, "Handler")) {
+              *type = $ix{'Response'}->{type};
+              return $ix{'Response'}->{name};
+          }
+EOF
+        }
+
         for my $name (@$names) {
             my $n = length($name);
             print $c_fh <<EOF;
@@ -375,7 +386,7 @@ sub generate_flags {
 
 EOF
             push @dumper,
-              qq{fprintf(stderr, " $name %s\\n", \\
+              qq{modperl_trace(NULL, " $name %s\\n", \\
                          ($flags(p) & $x) ? "On " : "Off");};
 
             $i += $i || 1;
@@ -388,7 +399,7 @@ EOF
         shift @dumper; #NONE
         print $h_fh join ' \\'."\n", 
           "#define ${class}_dump_flags(p, str)",
-                     qq{fprintf(stderr, "$class flags dump (%s):\\n", str);},
+                     qq{modperl_trace(NULL, "$class flags dump (%s):\\n", str);},
                      @dumper;
     }
 
@@ -427,8 +438,6 @@ sub generate_trace {
     my $tl = "MP_debug_level";
 
     print $h_fh <<EOF;
-extern U32 $tl;
-
 #define MP_TRACE_OPTS "$opts"
 
 #ifdef MP_TRACE
@@ -460,13 +469,13 @@ $define_do(exp)
 #endif
 EOF
         push @dumper,
-          qq{fprintf(stderr, " $type %s ($trace{$type})\\n", ($tl & $i) ? "On " : "Off");};
+          qq{modperl_trace(NULL, " $type %s ($trace{$type})\\n", ($tl & $i) ? "On " : "Off");};
         $i += $i;
     }
 
     print $h_fh join ' \\'."\n", 
                      '#define MP_TRACE_dump_flags()',
-                     qq{fprintf(stderr, "mod_perl trace flags dump:\\n");},
+                     qq{modperl_trace(NULL, "mod_perl trace flags dump:\\n");},
                      @dumper;
 
     ();
@@ -627,7 +636,7 @@ sub init_file {
     }
 
     my $file = "$self->{path}/$name";
-    warn "generating...$file\n";
+    debug "generating...$file";
     unlink $file;
     open my $fh, '>>', $file or die "open $file: $!";
     print $fh @preamble, noedit_warning_c();
@@ -659,7 +668,6 @@ sub generate {
     }
 
     for my $method (reverse sort keys %sources) {
-        print "$method...";
         my($h_fh, $c_fh) = map {
             $self->fh($sources{$method}->{$_});
         } qw(h c);
@@ -670,13 +678,13 @@ sub generate {
         if ($c_add) {
             print $c_fh $c_add;
         }
-        print "done\n";
+        debug "$method...done";
     }
 
     $self->postamble;
 
     my $xsinit = "$self->{path}/modperl_xsinit.c";
-    warn "generating...$xsinit\n";
+    debug "generating...$xsinit";
 
     #create bootstrap method for static xs modules
     my $static_xs = [keys %{ $build->{XS} }];
@@ -702,6 +710,7 @@ my %shortcuts = (
      FORBIDDEN => 'HTTP_FORBIDDEN',
      AUTH_REQUIRED => 'HTTP_UNAUTHORIZED',
      SERVER_ERROR => 'HTTP_INTERNAL_SERVER_ERROR',
+     REDIRECT => 'HTTP_MOVED_TEMPORARILY',
 );
 
 sub constants_lookup_code {
