@@ -164,6 +164,14 @@ MP_INLINE SV *modperl_ptr2obj(pTHX_ char *classname, void *ptr)
     return sv;
 }
 
+/* XXX: sv_setref_uv does not exist in 5.6.x */
+MP_INLINE SV *modperl_perl_sv_setref_uv(pTHX_ SV *rv,
+                                        const char *classname, UV uv)
+{
+    sv_setuv(newSVrv(rv, classname), uv);
+    return rv;
+}
+
 apr_pool_t *modperl_sv2pool(pTHX_ SV *obj)
 {
     apr_pool_t *p = NULL;
@@ -175,7 +183,7 @@ apr_pool_t *modperl_sv2pool(pTHX_ SV *obj)
      * get the pool from the current request
      * else return the global pool
      */
-    if (obj == &PL_sv_undef) {
+    if (!SvOK(obj)) {
         request_rec *r = NULL;
         (void)modperl_tls_get_request_rec(&r);
 
@@ -473,6 +481,14 @@ HE *modperl_perl_hv_fetch_he(pTHX_ HV *hv,
     return 0;
 }
 
+void modperl_str_toupper(char *str)
+{
+    while (*str) {
+        *str = apr_toupper(*str);
+        ++str;
+    }
+}
+
 /* XXX: same as Perl_do_sprintf(); 
  * but Perl_do_sprintf() is not part of the "public" api
  */
@@ -514,10 +530,15 @@ void modperl_perl_call_list(pTHX_ AV *subs, const char *name)
 
 void modperl_perl_exit(pTHX_ int status)
 {
+    const char *pat = NULL;
     ENTER;
     SAVESPTR(PL_diehook);
     PL_diehook = Nullsv; 
-    Perl_croak(aTHX_ NULL);
+    sv_setpv(ERRSV, "");
+#ifdef MP_PERL_5_6_0
+    pat = ""; /* NULL segvs in 5.6.0 */
+#endif
+    Perl_croak(aTHX_ pat);
 }
 
 MP_INLINE SV *modperl_dir_config(pTHX_ request_rec *r, server_rec *s,
@@ -527,7 +548,7 @@ MP_INLINE SV *modperl_dir_config(pTHX_ request_rec *r, server_rec *s,
 
     if (r && r->per_dir_config) {				   
         MP_dDCFG;
-        retval = modperl_table_get_set(aTHX_ dcfg->SetVar,
+        retval = modperl_table_get_set(aTHX_ dcfg->vars,
                                        key, sv_val, FALSE);
     }
 
@@ -535,7 +556,7 @@ MP_INLINE SV *modperl_dir_config(pTHX_ request_rec *r, server_rec *s,
         if (s && s->module_config) {
             MP_dSCFG(s);
             SvREFCNT_dec(retval); /* in case above did newSV(0) */
-            retval = modperl_table_get_set(aTHX_ scfg->SetVar,
+            retval = modperl_table_get_set(aTHX_ scfg->vars,
                                            key, sv_val, FALSE);
         }
         else {
@@ -558,7 +579,7 @@ SV *modperl_table_get_set(pTHX_ apr_table_t *table, char *key,
         retval = modperl_hash_tie(aTHX_ "APR::Table",
                                   Nullsv, (void*)table); 
     }
-    else if (sv_val == &PL_sv_no) { /* no val was passed */
+    else if (!sv_val) { /* no val was passed */
         char *val; 
         if ((val = (char *)apr_table_get(table, key))) { 
             retval = newSVpv(val, 0); 
@@ -570,7 +591,7 @@ SV *modperl_table_get_set(pTHX_ apr_table_t *table, char *key,
             SvTAINTED_on(retval); 
         } 
     }
-    else if (sv_val == &PL_sv_undef) { /* val was passed in as undef */
+    else if (!SvOK(sv_val)) { /* val was passed in as undef */
         apr_table_unset(table, key); 
     }
     else { 
