@@ -1,3 +1,6 @@
+use Socket (); #test DynaLoader vs. XSLoader workaround for 5.6.x
+use IO::File ();
+
 use Apache2 ();
 
 use ModPerl::Util (); #for CORE::GLOBAL::exit
@@ -22,6 +25,10 @@ unless ($ENV{MOD_PERL}) {
     die '$ENV{MOD_PERL} not set!';
 }
 
+#see t/modperl/methodobj
+use TestModperl::methodobj ();
+$TestModperl::MethodObj = TestModperl::methodobj->new;
+
 #see t/response/TestModperl/env.pm
 $ENV{MODPERL_EXTRA_PL} = __FILE__;
 
