@@ -3,11 +3,16 @@ package TestFilter::buckets;
 use strict;
 use warnings FATAL => 'all';
 
-use Test;
+use Apache::Test;
+
+use Apache::RequestRec ();
+use Apache::RequestIO ();
 use Apache::Filter ();
 use APR::Brigade ();
 use APR::Bucket ();
 
+use Apache::Const -compile => 'OK';
+
 sub handler {
     my($filter, $bb) = @_;
 
