@@ -3,10 +3,13 @@ package TestAPI::r_subclass;
 use strict;
 use warnings FATAL => 'all';
 
+use Apache::RequestRec ();
 our @ISA = qw(Apache::RequestRec);
 
 use Apache::Test;
 
+use Apache::Const -compile => 'OK';
+
 sub new {
     my $class = shift;
     my $r = shift;
@@ -18,7 +21,9 @@ my $location = '/' . __PACKAGE__;
 sub handler {
     my $r = __PACKAGE__->new(shift);
 
-    plan $r, tests => 4;
+    plan $r, tests => 5;
+
+    ok ! Apache->request;
 
     ok $r->uri eq $location;
 
@@ -36,3 +41,6 @@ sub handler {
 }
 
 1;
+__END__
+SetHandler perl-script
+PerlOptions -GlobalRequest
