@@ -3,8 +3,12 @@ package TestModperl::print;
 use strict;
 use warnings FATAL => 'all';
 
+use Apache::RequestIO ();
+
 use Apache::Test;
 
+use Apache::Const -compile => 'OK';
+
 sub handler {
     my $r = shift;
 
